@@ -20,7 +20,7 @@ use Types::Standard qw/ Bool CodeRef HashRef Maybe Tuple /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.1';
+our $VERSION = 'v0.2.2';
 
 
 
@@ -214,17 +214,17 @@ sub inline_html {
 
 sub link_or_inline_html {
     my ($self, @names ) = @_;
+    my $buffer = "";
     foreach my $name (uniqstr @names) {
-        croak "missing name" unless defined $name;
-        my $file = $self->css_files->{$name};
-        croak "invalid name '$name'" unless defined $file;
+        my $file = $self->css_files->{$name} or croak "invalid name '$name'";
         if ( $file->[PATH] && ($file->[SIZE] <= $self->inline_max)) {
-            return $self->inline_html($name, $file);
+            $buffer .= $self->inline_html($name, $file);
         }
         else {
-            return $self->link_html($name, $file);
+            $buffer .= $self->link_html($name, $file);
         }
     }
+    return $buffer;
 }
 
 
@@ -277,7 +277,7 @@ HTML::DeferableCSS - Simplify management of stylesheets in your HTML
 
 =head1 VERSION
 
-version v0.2.1
+version v0.2.2
 
 =head1 SYNOPSIS
 
